@@ -5,7 +5,8 @@ from .read_xyz import Xyz
 from .generate_fort5 import generate_uniform_random, generate_fcc
 from .replace_in_fort1 import replace_in_fort1
 from .replace_in_fort3 import Fort3Replacement, replace_in_fort3
+from .histogram import histogram
 
 __all__ = ['OccamData', 'Fort1', 'Fort7', 'Xyz', 'generate_uniform_random',
            'generate_fcc', 'replace_in_fort1', 'Fort3Replacement',
-           'replace_in_fort3']
+           'replace_in_fort3', 'histogram']
